@@ -1,4 +1,4 @@
-"""
+'''
 # aws-lambda-dynamodb module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -102,7 +102,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -136,7 +136,7 @@ class LambdaToDynamoDB(
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
@@ -148,7 +148,7 @@ class LambdaToDynamoDB(
         :access: public
         :since: 0.8.0
         :summary: Constructs a new instance of the LambdaToDynamoDB class.
-        """
+        '''
         props = LambdaToDynamoDBProps(
             dynamo_table_props=dynamo_table_props,
             existing_lambda_obj=existing_lambda_obj,
@@ -191,7 +191,7 @@ class LambdaToDynamoDBProps:
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
-        """
+        '''
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
@@ -199,7 +199,7 @@ class LambdaToDynamoDBProps:
         :param table_permissions: Optional table permissions to grant to the Lambda function. One of the following may be specified: "All", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
 
         :summary: The properties for the LambdaToDynamoDB Construct
-        """
+        '''
         if isinstance(dynamo_table_props, dict):
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
@@ -218,28 +218,28 @@ class LambdaToDynamoDBProps:
 
     @builtins.property
     def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
-        """Optional user provided props to override the default props.
+        '''Optional user provided props to override the default props.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("dynamo_table_props")
         return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.TableProps], result)
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
+        '''Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_lambda_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
     @builtins.property
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
-        """Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored.
+        '''Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_table_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.Table], result)
 
@@ -247,21 +247,21 @@ class LambdaToDynamoDBProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """User provided props to override the default props for the Lambda function.
+        '''User provided props to override the default props for the Lambda function.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("lambda_function_props")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
     @builtins.property
     def table_permissions(self) -> typing.Optional[builtins.str]:
-        """Optional table permissions to grant to the Lambda function.
+        '''Optional table permissions to grant to the Lambda function.
 
         One of the following may be specified: "All", "Read", "ReadWrite", "Write".
 
         :default: - Read/write access is given to the Lambda function if no value is specified.
-        """
+        '''
         result = self._values.get("table_permissions")
         return typing.cast(typing.Optional[builtins.str], result)
 
